# Input/Output

Functions for reading and writing AnnData objects optimized for seqlet analysis.

```{eval-rst}
.. currentmodule:: tfmindi

.. autosummary::
    :toctree: ../generated

    save_h5ad
    load_h5ad
    save_patterns
    load_patterns
```
